<?php
/**
 * Plugin Name: ShopMagic Abandoned Carts
 * Plugin URI: https://shopmagic.app/products/shopmagic-abandoned-carts/?utm_source=add_plugin_details&utm_medium=link&utm_campaign=plugin_homepage
 * Description: Allows saving customer details on a partial WooCommerce purchase and send abandoned cart emails.
 * Version: 2.1.1
 * Author: WP Desk
 * Author URI: https://shopmagic.app/?utm_source=user-site&utm_medium=quick-link&utm_campaign=author
 * Text Domain: shopmagic-abandoned-carts
 * Domain Path: /lang/
 * Requires at least: 5.0
 * Tested up to: 6.0
 * WC requires at least: 6.0
 * WC tested up to: 6.6.1
 * Requires PHP: 7.0
 *
 * Copyright 2020 WP Desk Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

/* THESE TWO VARIABLES CAN BE CHANGED AUTOMATICALLY */
$plugin_version = '2.1.1';

$plugin_name        = 'ShopMagic Abandoned Carts';
$plugin_class_name  = '\WPDesk\ShopMagicCart\Plugin';
$product_id         = '';
$plugin_text_domain = 'shopmagic-abandoned-carts';
$plugin_file        = __FILE__;
$plugin_dir         = __DIR__;

$requirements = [
	'php'     => '7.0',
	'wp'      => '5.0',
	'plugins' => [
		[
			'name'      => 'shopmagic-for-woocommerce/shopMagic.php',
			'nice_name' => 'ShopMagic',
			'version'   => '2.37.1',
		],
	],
];

if ( \PHP_VERSION_ID > 50300 ) {
	require_once $plugin_dir . '/vendor/autoload.php';

	$requirements_checker = ( new \ShopMagicCartVendor\WPDesk_Basic_Requirement_Checker_Factory() )
		->create_from_requirement_array(
			__FILE__,
			$plugin_name,
			$requirements,
			$plugin_text_domain
		);

	$plugin_info = new \ShopMagicCartVendor\WPDesk_Plugin_Info();
	$plugin_info->set_plugin_file_name( plugin_basename( $plugin_file ) );
	$plugin_info->set_plugin_name( $plugin_name );
	$plugin_info->set_plugin_dir( $plugin_dir );
	$plugin_info->set_class_name( $plugin_class_name );
	$plugin_info->set_version( $plugin_version );
	$plugin_info->set_product_id( $product_id );
	$plugin_info->set_text_domain( $plugin_text_domain );
	$plugin_info->set_plugin_url( plugins_url( dirname( plugin_basename( $plugin_file ) ) ) );

	add_action(
		'plugins_loaded',
		static function () use ( $requirements_checker, $plugin_info, $plugin_class_name ) {
			if ( $requirements_checker->are_requirements_met() ) {
				$plugin = new $plugin_class_name( $plugin_info );
				$plugin->init();
			} else {
				$requirements_checker->render_notices();
			}
		},
		- 50
	);
}
