<?php

declare( strict_types=1 );

namespace WPDesk\ShopMagicCart\Admin\CartsMenu;

use ShopMagicVendor\WPDesk\View\Renderer\SimplePhpRenderer;
use ShopMagicVendor\WPDesk\View\Resolver\DirResolver;
use WPDesk\ShopMagic\Automation\AutomationPostType;
use WPDesk\ShopMagic\Helper\CapabilitiesCheckTrait;
use WPDesk\ShopMagicCart\Cart\CartStatistics;
use WPDesk\ShopMagicCart\Cart\CartTable;

final class ListMenu {
	use CapabilitiesCheckTrait;
	const SLUG                 = 'carts';
	const POSITION_AFTER_GUEST = 7;

	/** @var CartTable */
	private $cart_dao;

	/** @var CartStatistics */
	private $stats;

	public function __construct( CartTable $cart_dao, CartStatistics $stats ) {
		$this->cart_dao = $cart_dao;
		$this->stats    = $stats;
	}

	/** @return void */
	public function hooks() {
		add_action(
			'admin_menu',
			function () {
				$capability = $this->allowed_capability();
				if ( $capability ) {
					add_submenu_page(
						AutomationPostType::POST_TYPE_MENU_URL,
						__( 'Cart', 'shopmagic-abandoned-carts' ),
						__( 'Carts', 'shopmagic-abandoned-carts' ),
						$capability,
						self::SLUG,
						[ $this, 'render_page_action' ],
						self::POSITION_AFTER_GUEST
					);
				}
			}
		);
	}

	public static function get_url(): string {
		$params = [
			'page' => self::SLUG,
		];

		return AutomationPostType::get_url() . '&' . http_build_query( $params );
	}

	/**
	 * @return void
	 * @internal
	 */
	public function render_page_action() {
		$cart_table = new TableList( $this->cart_dao );
		$cart_table->prepare_items();

		$renderer = ( new SimplePhpRenderer( new DirResolver( __DIR__ . DIRECTORY_SEPARATOR . 'templates' ) ) );
		$renderer->output_render(
			'table',
			[
				'carts_table' => $cart_table,
				'stats'       => $this->stats,
			]
		);
	}
}
